@@ -29,7 +29,7 @@ def init_cacheify(app, config=None):
 
     # Look for RedisGreen.
     if any([k.startswith('REDISGREEN_') for k in environ]):
-        config.setdefault('CACHE_TYPE', 'redis')
+        config['CACHE_TYPE'] = 'redis'
         config.setdefault('CACHE_REDIS_URL', environ.get('REDISGREEN_URL'))
 
     return Cache(app, config)
